=== modified file 'Makefile'
--- Makefile	2011-03-14 08:47:03 +0000
+++ Makefile	2007-10-29 16:19:30 +0000
@@ -8,4 +8,5 @@
 	rm -rf dist/
 
 check:
-	BZR_PLUGINS_AT=loggerhead@$$(pwd) bzr selftest -s bp.loggerhead
+	# XXX MichaelHudson 2007-10-29 bug=158361: We can't run the loggerhead
+	# tests in PQM yet :(

=== modified file 'NEWS'
--- NEWS	2011-03-16 12:24:06 +0000
+++ NEWS	2011-03-04 15:49:43 +0000
@@ -16,18 +16,12 @@
     - Merge the pqm changes back into trunk, after trunk was reverted to an old
       revision. (John Arbash Meinel, #716152)
 
-    - Redirect ``/files/file.txt`` to ``/view/file.txt`` and ``/view/dir`` to
-      ``/files/dir``. (Jasper St. Pierre, #569358)
+    - The json module is no longer claimed to be supported as alternative for 
+      simplejson. (Jelmer Vernooij, #586611)
 
     - Remove ``start-loggerhead`` and ``stop-loggerhead`` which were already
       deprecated. (John Arbash Meinel)
 
-    - Show "Author(s)" as separate from "Committer". And label them
-      correctly. (John Arbash Meinel, #733015)
-
-    - The json module is no longer claimed to be supported as alternative for 
-      simplejson. (Jelmer Vernooij, #586611)
-
 
 1.18 [10Nov2010]
 ----------------

=== modified file '__init__.py'
--- __init__.py	2011-03-16 12:29:36 +0000
+++ __init__.py	2011-02-10 01:57:32 +0000
@@ -30,8 +30,6 @@
 starts a web server to browse the contents of a branch.
 """
 
-import sys
-
 from info import (
     bzr_plugin_version as version_info,
     bzr_compatible_versions,
@@ -51,6 +49,17 @@
     HELP = ('Loggerhead, a web-based code viewer and server. (default port: %d)' %
             (DEFAULT_PORT,))
 
+    def setup_logging(config):
+        import logging
+        import sys
+
+        logger = logging.getLogger('loggerhead')
+        handler = logging.StreamHandler(sys.stderr)
+        handler.setLevel(logging.DEBUG)
+        logger.addHandler(handler)
+        logging.getLogger('simpleTAL').addHandler(handler)
+        logging.getLogger('simpleTALES').addHandler(handler)
+
     def _ensure_loggerhead_path():
         """Ensure that you can 'import loggerhead' and get the root."""
         # loggerhead internal code will try to 'import loggerhead', so
@@ -69,7 +78,6 @@
 
         from loggerhead.apps.transport import BranchesFromTransportRoot
         from loggerhead.config import LoggerheadConfig
-        from loggerhead.main import setup_logging
 
         if host is None:
             host = DEFAULT_HOST
@@ -79,7 +87,7 @@
         if not transport.is_readonly():
             argv.insert(0, '--allow-writes')
         config = LoggerheadConfig(argv)
-        setup_logging(config, init_logging=False, log_file=sys.stderr)
+        setup_logging(config)
         app = BranchesFromTransportRoot(transport.base, config)
         app = HTTPExceptionHandler(app)
         serve(app, host=host, port=port)

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2011-03-16 11:40:05 +0000
+++ loggerhead/apps/transport.py	2010-05-05 18:35:35 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2011 Canonical Ltd.
+# Copyright (C) 2008, 2009 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'loggerhead/config.py'
--- loggerhead/config.py	2010-05-12 14:38:05 +0000
+++ loggerhead/config.py	2010-04-13 23:35:01 +0000
@@ -49,12 +49,6 @@
     parser.add_option("--protocol", dest="protocol",
                       help=("Protocol to use: http, scgi, fcgi, ajp"
                            "(defaults to http)."))
-    parser.add_option("--log-level", default=None, action='callback',
-                      callback=_optparse_level_to_int_level,
-                      type="string",
-                      help="Set the verbosity of logging. Can either"
-                           " be set to a numeric or string"
-                           " (eg, 10=debug, 30=warning)")
     parser.add_option("--memory-profile", action="store_true",
                       help="Profile the memory usage using Dozer.")
     parser.add_option("--prefix", dest="user_prefix",
@@ -78,29 +72,6 @@
     return parser
 
 
-_log_levels = {
-    'debug': 10,
-    'info': 20,
-    'warning': 30,
-    'error': 40,
-    'critical': 50,
-}
-
-def _optparse_level_to_int_level(option, opt_str, value, parser):
-    parser.values.log_level = _level_to_int_level(value)
-
-
-def _level_to_int_level(value):
-    """Convert a string level to an integer value."""
-    if value is None:
-        return None
-    try:
-        return int(value)
-    except ValueError:
-        pass
-    return _log_levels[value.lower()]
-
-
 class LoggerheadConfig(object):
     """A configuration object."""
 
@@ -128,10 +99,6 @@
         else:
             return cmd_config
 
-    def get_log_level(self):
-        opt = self.get_option('log_level')
-        return _level_to_int_level(opt)
-
     def get_arg(self, index):
         """Get an arg from the arg list."""
         return self._args[index]

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2011-03-16 11:40:05 +0000
+++ loggerhead/controllers/__init__.py	2011-02-10 17:01:10 +0000
@@ -94,7 +94,7 @@
 
         vals.update(self.get_values(path, kwargs, headers))
 
-        self.log.info('Getting information for %s: %.3f secs' % (
+        self.log.info('Getting information for %s: %r secs' % (
             self.__class__.__name__, time.time() - z))
         if 'Content-Type' not in headers:
             headers['Content-Type'] = 'text/html'
@@ -108,7 +108,7 @@
         template.expand_into(w, **vals)
         w.flush()
         self.log.info(
-            'Rendering %s: %.3f secs, %s bytes' % (
+            'Rendering %s: %r secs, %s bytes' % (
                 self.__class__.__name__, time.time() - z, w.bytes))
         return []
 

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2011-03-12 17:15:08 +0000
+++ loggerhead/controllers/inventory_ui.py	2009-03-19 00:44:05 +0000
@@ -22,7 +22,7 @@
 import posixpath
 import urllib
 
-from paste.httpexceptions import HTTPNotFound, HTTPMovedPermanently
+from paste.httpexceptions import HTTPNotFound
 
 from bzrlib import errors
 from bzrlib.revision import is_null as is_null_rev
@@ -45,7 +45,7 @@
 
     template_path = 'loggerhead.templates.inventory'
 
-    def get_filelist(self, inv, path, sort_type, revno_url):
+    def get_filelist(self, inv, path, sort_type):
         """
         return the list of all files (and their attributes) within a given
         path subtree.
@@ -58,9 +58,6 @@
         dir_ie = inv[file_id]
         file_list = []
 
-        if dir_ie.kind != 'directory':
-            raise HTTPMovedPermanently(self._branch.context_url(['/view', revno_url, path]))
-
         revid_set = set()
 
         for filename, entry in dir_ie.children.iteritems():
@@ -153,7 +150,7 @@
 
             # Create breadcrumb trail for the path within the branch
             branch_breadcrumbs = util.branch_breadcrumbs(path, rev_tree, 'files')
-            filelist = self.get_filelist(rev_tree.inventory, path, sort_type, revno_url)
+            filelist = self.get_filelist(rev_tree.inventory, path, sort_type)
         else:
             start_revid = None
             change = None

=== modified file 'loggerhead/controllers/view_ui.py'
--- loggerhead/controllers/view_ui.py	2011-03-12 17:15:08 +0000
+++ loggerhead/controllers/view_ui.py	2010-12-01 08:30:02 +0000
@@ -25,7 +25,7 @@
 import bzrlib.textfile
 import bzrlib.osutils
 
-from paste.httpexceptions import HTTPBadRequest, HTTPServerError, HTTPMovedPermanently
+from paste.httpexceptions import HTTPBadRequest, HTTPServerError
 
 from loggerhead.controllers import TemplatedBranchView
 try:
@@ -120,9 +120,6 @@
             raise HTTPServerError('Could not fetch changes')
         branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
 
-        if inv[file_id].kind == "directory":
-            raise HTTPMovedPermanently(self._branch.context_url(['/files', revno_url, path]))
-
         return {
             # In AnnotateUI, "annotated" is a generator giving revision
             # numbers per lines, but the template checks if "annotated" is

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2011-03-11 10:43:39 +0000
+++ loggerhead/history.py	2010-05-10 13:48:25 +0000
@@ -35,7 +35,6 @@
 import textwrap
 import threading
 
-from bzrlib import tag
 import bzrlib.branch
 import bzrlib.delta
 import bzrlib.errors
@@ -328,16 +327,7 @@
         revid in revid_list.
         """
         if revid_list is None:
-            # Just yield the mainline, starting at start_revid
-            revid = start_revid
-            is_null = bzrlib.revision.is_null
-            while not is_null(revid):
-                yield revid
-                parents = self._rev_info[self._rev_indices[revid]][2]
-                if not parents:
-                    return
-                revid = parents[0]
-            return
+            revid_list = [r[0][1] for r in self._rev_info]
         revid_set = set(revid_list)
         revid = start_revid
 
@@ -680,17 +670,12 @@
 
         revtags = None
         if revision.revision_id in self._branch_tags:
-          # tag.sort_* functions expect (tag, data) pairs, so we generate them,
-          # and then strip them
-          tags = [(t, None) for t in self._branch_tags[revision.revision_id]]
-          tag.sort_natural(self._branch, tags)
-          revtags = u', '.join([t[0] for t in tags])
+          revtags = ', '.join(self._branch_tags[revision.revision_id])
 
         entry = {
             'revid': revision.revision_id,
             'date': datetime.datetime.fromtimestamp(revision.timestamp),
             'utc_date': datetime.datetime.utcfromtimestamp(revision.timestamp),
-            'committer': revision.committer,
             'authors': revision.get_apparent_authors(),
             'branch_nick': revision.properties.get('branch-nick', None),
             'short_comment': short_message,

=== modified file 'loggerhead/main.py'
--- loggerhead/main.py	2011-03-16 11:39:27 +0000
+++ loggerhead/main.py	2009-11-27 18:30:24 +0000
@@ -56,39 +56,21 @@
     return config, base
 
 
-def setup_logging(config, init_logging=True, log_file=None):
-    log_level = config.get_log_level()
-    if init_logging:
-        logging.basicConfig()
-        if log_level is not None:
-            logging.getLogger('').setLevel(log_level)
+def setup_logging(config):
+    logging.basicConfig()
+    logging.getLogger('').setLevel(logging.DEBUG)
     logger = logging.getLogger('loggerhead')
-    if log_level is not None:
-        logger.setLevel(log_level)
-    if log_file is not None:
-        handler = logging.StreamHandler(log_file)
+    if config.get_option('log_folder'):
+        logfile_path = os.path.join(
+            config.get_option('log_folder'), 'serve-branches.log')
     else:
-        if config.get_option('log_folder'):
-            logfile_path = os.path.join(
-                config.get_option('log_folder'), 'serve-branches.log')
-        else:
-            logfile_path = 'serve-branches.log'
-        handler = logging.FileHandler(logfile_path, 'a')
-        formatter = logging.Formatter('%(asctime)s %(levelname)-8s %(name)s:'
-                                      ' %(message)s')
-        handler.setFormatter(formatter)
-    # We set the handler to accept all messages, the *logger* won't emit them
-    # if it is configured to suppress it
-    handler.setLevel(logging.DEBUG)
-    logger.addHandler(handler)
-    def _restrict_logging(logger_name):
-        logger = logging.getLogger(logger_name)
-        if logger.getEffectiveLevel() < logging.INFO:
-            logger.setLevel(logging.INFO)
-    # simpleTAL is *very* verbose in DEBUG mode, which is otherwise the
-    # default. So quiet it up a bit.
-    _restrict_logging('simpleTAL')
-    _restrict_logging('simpleTALES')
+        logfile_path = 'serve-branches.log'
+    logfile = logging.FileHandler(logfile_path, 'a')
+    formatter = logging.Formatter('%(asctime)s %(levelname)-8s %(name)s:'
+                                  ' %(message)s')
+    logfile.setFormatter(formatter)
+    logfile.setLevel(logging.DEBUG)
+    logger.addHandler(logfile)
     return logger
 
 

=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2011-03-16 12:37:17 +0000
+++ loggerhead/templates/revisioninfo.pt	2011-02-18 05:41:17 +0000
@@ -3,10 +3,6 @@
         <ul>
             <li class="committer">
                 <strong>Committer:</strong>
-                <span tal:content="python:util.hide_email(change.committer)"></span>
-            </li>
-            <li class="authors" tal:condition="python:len(change.authors) > 1 or change.authors[0] != change.committer">
-                <strong>Author(s):</strong>
                 <span tal:content="python:', '.join(util.hide_emails(change.authors))"></span>
             </li>
             <li class="timer">

=== modified file 'loggerhead/tests/__init__.py'
--- loggerhead/tests/__init__.py	2011-03-16 12:24:06 +0000
+++ loggerhead/tests/__init__.py	2011-02-10 23:06:59 +0000
@@ -20,10 +20,8 @@
         (__name__ + '.' + x) for x in [
             'test_controllers',
             'test_corners',
-            'test_history',
             'test_load_test',
             'test_simple',
-            'test_revision_ui',
             'test_templating',
         ]]))
     return standard_tests

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2011-03-15 02:56:59 +0000
+++ loggerhead/tests/test_controllers.py	2011-02-10 17:01:10 +0000
@@ -47,7 +47,7 @@
         bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
             ['filename'])
         inv = bzrbranch.repository.get_inventory(bzrbranch.last_revision())
-        self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename', 'head')))
+        self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename')))
 
     def test_smoke(self):
         bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(

=== removed file 'loggerhead/tests/test_history.py'
--- loggerhead/tests/test_history.py	2011-03-11 10:43:39 +0000
+++ loggerhead/tests/test_history.py	1970-01-01 00:00:00 +0000
@@ -1,173 +0,0 @@
-# Copyright (C) 2011 Canonical Ltd.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-"""Direct tests of the loggerhead/history.py module"""
-
-from datetime import datetime
-from bzrlib import tests
-
-from loggerhead import history as _mod_history
-
-
-class TestHistoryGetRevidsFrom(tests.TestCaseWithMemoryTransport):
-
-    def make_linear_ancestry(self):
-        # Time goes up
-        # rev-3
-        #  |
-        # rev-2
-        #  |
-        # rev-1
-        builder = self.make_branch_builder('branch')
-        builder.start_series()
-        builder.build_snapshot('rev-1', None, [
-            ('add', ('', 'root-id', 'directory', None))])
-        builder.build_snapshot('rev-2', ['rev-1'], [])
-        builder.build_snapshot('rev-3', ['rev-2'], [])
-        builder.finish_series()
-        b = builder.get_branch()
-        self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
-
-    def make_merged_ancestry(self):
-        # Time goes up
-        # rev-3
-        #  |  \
-        #  |  rev-2
-        #  |  /
-        # rev-1
-        builder = self.make_branch_builder('branch')
-        builder.start_series()
-        builder.build_snapshot('rev-1', None, [
-            ('add', ('', 'root-id', 'directory', None))])
-        builder.build_snapshot('rev-2', ['rev-1'], [])
-        builder.build_snapshot('rev-3', ['rev-1', 'rev-2'], [])
-        builder.finish_series()
-        b = builder.get_branch()
-        self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
-
-    def make_deep_merged_ancestry(self):
-        # Time goes up
-        # F
-        # |\
-        # | E
-        # | |\
-        # | | D
-        # | |/
-        # B C
-        # |/
-        # A
-        builder = self.make_branch_builder('branch')
-        builder.start_series()
-        builder.build_snapshot('A', None, [
-            ('add', ('', 'root-id', 'directory', None))])
-        builder.build_snapshot('B', ['A'], [])
-        builder.build_snapshot('C', ['A'], [])
-        builder.build_snapshot('D', ['C'], [])
-        builder.build_snapshot('E', ['C', 'D'], [])
-        builder.build_snapshot('F', ['B', 'E'], [])
-        builder.finish_series()
-        b = builder.get_branch()
-        self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
-
-    def assertRevidsFrom(self, expected, history, search_revs, tip_rev):
-        self.assertEqual(expected,
-                         list(history.get_revids_from(search_revs, tip_rev)))
-
-    def test_get_revids_from_simple_mainline(self):
-        history = self.make_linear_ancestry()
-        self.assertRevidsFrom(['rev-3', 'rev-2', 'rev-1'],
-                              history, None, 'rev-3')
-
-    def test_get_revids_from_merged_mainline(self):
-        history = self.make_merged_ancestry()
-        self.assertRevidsFrom(['rev-3', 'rev-1'],
-                              history, None, 'rev-3')
-
-    def test_get_revids_given_one_rev(self):
-        history = self.make_merged_ancestry()
-        # rev-3 was the first mainline revision to see rev-2.
-        self.assertRevidsFrom(['rev-3'], history, ['rev-2'], 'rev-3')
-
-    def test_get_revids_deep_ancestry(self):
-        history = self.make_deep_merged_ancestry()
-        self.assertRevidsFrom(['F'], history, ['F'], 'F')
-        self.assertRevidsFrom(['F'], history, ['E'], 'F')
-        self.assertRevidsFrom(['F'], history, ['D'], 'F')
-        self.assertRevidsFrom(['F'], history, ['C'], 'F')
-        self.assertRevidsFrom(['B'], history, ['B'], 'F')
-        self.assertRevidsFrom(['A'], history, ['A'], 'F')
-
-
-class TestHistoryChangeFromRevision(tests.TestCaseWithTransport):
-
-    def make_single_commit(self):
-        tree = self.make_branch_and_tree('test')
-        rev_id = tree.commit('Commit Message', timestamp=1299838474.317,
-            timezone=3600, committer='Joe Example <joe@example.com>',
-            revprops={})
-        self.addCleanup(tree.branch.lock_write().unlock)
-        rev = tree.branch.repository.get_revision(rev_id)
-        history = _mod_history.History(tree.branch, {})
-        return history, rev
-
-    def test_simple(self):
-        history, rev = self.make_single_commit()
-        change = history._change_from_revision(rev)
-        self.assertEqual(rev.revision_id, change.revid)
-        self.assertEqual(datetime.fromtimestamp(1299838474.317),
-                         change.date)
-        self.assertEqual(datetime.utcfromtimestamp(1299838474.317),
-                         change.utc_date)
-        self.assertEqual(['Joe Example <joe@example.com>'],
-                         change.authors)
-        self.assertEqual('test', change.branch_nick)
-        self.assertEqual('Commit Message', change.short_comment)
-        self.assertEqual('Commit Message', change.comment)
-        self.assertEqual(['Commit&nbsp;Message'], change.comment_clean)
-        self.assertEqual([], change.parents)
-        self.assertEqual([], change.bugs)
-        self.assertEqual(None, change.tags)
-
-    def test_tags(self):
-        history, rev = self.make_single_commit()
-        b = history._branch
-        b.tags.set_tag('tag-1', rev.revision_id)
-        b.tags.set_tag('tag-2', rev.revision_id)
-        b.tags.set_tag('Tag-10', rev.revision_id)
-        change = history._change_from_revision(rev)
-        # tags are 'naturally' sorted, sorting numbers in order, and ignoring
-        # case, etc.
-        self.assertEqual('tag-1, tag-2, Tag-10', change.tags)
-
-    def test_committer_vs_authors(self):
-        tree = self.make_branch_and_tree('test')
-        rev_id = tree.commit('Commit Message', timestamp=1299838474.317,
-            timezone=3600, committer='Joe Example <joe@example.com>',
-            revprops={'authors': u'A Author <aauthor@example.com>\n'
-                                 u'B Author <bauthor@example.com>'})
-        self.addCleanup(tree.branch.lock_write().unlock)
-        rev = tree.branch.repository.get_revision(rev_id)
-        history = _mod_history.History(tree.branch, {})
-        change = history._change_from_revision(rev)
-        self.assertEqual(u'Joe Example <joe@example.com>',
-                         change.committer)
-        self.assertEqual([u'A Author <aauthor@example.com>',
-                          u'B Author <bauthor@example.com>'],
-                         change.authors)

=== removed file 'loggerhead/tests/test_revision_ui.py'
--- loggerhead/tests/test_revision_ui.py	2011-03-16 12:37:17 +0000
+++ loggerhead/tests/test_revision_ui.py	1970-01-01 00:00:00 +0000
@@ -1,46 +0,0 @@
-# Copyright (C) 2011 Canonical Ltd.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-
-from loggerhead.tests.test_simple import BasicTests
-
-
-class TestRevisionUI(BasicTests):
-
-    def test_authors_vs_committer(self):
-        self.createBranch()
-        self.tree.commit('First', committer="Joe Example <joe@example.com>",
-            revprops={'authors': u'A Author <aauthor@example.com>\n'
-                                 u'B Author <bauthor@example.com>'})
-        app = self.setUpLoggerhead()
-        res = app.get('/revision/1')
-        # We would like to assert that Joe Example is connected to Committer,
-        # and the Authors are connected. However, that requires asserting the
-        # exact HTML connections, which I wanted to avoid.
-        res.mustcontain('Committer', 'Joe Example',
-                        'Author(s)', 'A Author, B Author')
-
-    def test_author_is_committer(self):
-        self.createBranch()
-        self.tree.commit('First', committer="Joe Example <joe@example.com>")
-        app = self.setUpLoggerhead()
-        res = app.get('/revision/1')
-        # We would like to assert that Joe Example is connected to Committer,
-        # and the Authors are connected. However, that requires asserting the
-        # exact HTML connections, which I wanted to avoid.
-        res.mustcontain('Committer', 'Joe Example')
-        self.assertFalse('Author(s)' in res.body)

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2011-03-15 10:24:40 +0000
+++ loggerhead/tests/test_simple.py	2011-03-10 14:22:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd.
+# Copyright (C) 2007-2011 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 from loggerhead.apps.branch import BranchWSGIApp
 from paste.fixture import TestApp
-from paste.httpexceptions import HTTPExceptionHandler, HTTPMovedPermanently
+from paste.httpexceptions import HTTPExceptionHandler
 
 
 
@@ -170,33 +170,6 @@
         res = app.get('/changes', status=404)
 
 
-class TestControllerRedirects(BasicTests):
-    """
-    Test that a file under /files redirects to /view,
-    and a directory under /view redirects to /files.
-    """
-
-    def setUp(self):
-        BasicTests.setUp(self)
-        self.createBranch()
-        self.build_tree(('file', 'folder/', 'folder/file'))
-        self.tree.smart_add([])
-        self.tree.commit('')
-
-    def test_view_folder(self):
-        app = TestApp(BranchWSGIApp(self.tree.branch, '').app)
-
-        e = self.assertRaises(HTTPMovedPermanently, app.get, '/view/head:/folder')
-        self.assertEqual(e.location(), '/files/head:/folder')
-
-    def test_files_file(self):
-        app = TestApp(BranchWSGIApp(self.tree.branch, '').app)
-
-        e = self.assertRaises(HTTPMovedPermanently, app.get, '/files/head:/folder/file')
-        self.assertEqual(e.location(), '/view/head:/folder/file')
-        e = self.assertRaises(HTTPMovedPermanently, app.get, '/files/head:/file')
-        self.assertEqual(e.location(), '/view/head:/file')
-
 #class TestGlobalConfig(BasicTests):
 #    """
 #    Test that global config settings are respected

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2010-04-26 19:37:26 +0000
+++ loggerhead/wholehistory.py	2009-10-21 14:40:23 +0000
@@ -80,6 +80,6 @@
             if revid not in c[1]:
                 c[1] = c[1] + (revid,)
 
-    log.info('built revision graph cache: %.3f secs' % (time.time() - z,))
+    log.info('built revision graph cache: %r secs' % (time.time() - z,))
 
     return (_rev_info, _rev_indices)

=== modified file 'loggerhead/zptsupport.py'
--- loggerhead/zptsupport.py	2010-05-12 15:01:44 +0000
+++ loggerhead/zptsupport.py	2009-03-02 05:44:20 +0000
@@ -23,6 +23,10 @@
 
 from simpletal import simpleTAL, simpleTALES
 
+logging.getLogger("simpleTAL").setLevel(logging.INFO)
+logging.getLogger("simpleTALES").setLevel(logging.INFO)
+
+
 _zpt_cache = {}
 
 

